timeintervaltools.shift_aggregate_offset_by_rational
====================================================

.. autofunction:: abjad.tools.timeintervaltools.shift_aggregate_offset_by_rational.shift_aggregate_offset_by_rational
